#
# spec file for package opensesame
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define src_name OpenSesame-release
Name:           opensesame
Version:        3.0.7
Release:        2.108
Summary:        Graphical experiment builder for the social sciences
License:        GPL-3.0
Group:          Productivity/Scientific/Other
Url:            http://osdoc.cogsci.nl/
Source0:        https://github.com/smathot/OpenSesame/archive/release/2.9.7.tar.gz#/%{src_name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM invalid-desktopfile.patch avvissu@yandex.ru-- Add semicolon (';') as trailing character
Patch0:         opensesame-2.9.6_invalid-desktopfile.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-base
BuildRequires:  python-pygame >= 1.8.1
BuildRequires:  python-qscintilla
BuildRequires:  python-qt4-devel
BuildRequires:  python-yaml
Requires:       python-markdown
Requires:       python-numpy >= 1.3.0
Requires:       python-pygame >= 1.8.1
Requires:       python-qprogedit >= 3.0.0
Requires:       python-qscintilla
Requires:       python-qt4
Requires:       python-simplejson
Requires:       python-webcolors
Requires:       python-yaml
Recommends:     IPython
Recommends:     python-PsychoPy >= 1.64.0
Recommends:     python-PyAudio
Recommends:     python-expyriment >= 0.5.2
Recommends:     python-imaging >= 1.1.7
Recommends:     python-opengl >= 3.0.1
Recommends:     python-pyserial >= 2.3.0
BuildArch:      noarch

%description
OpenSesame is a graphical, open-source experiment builder for the social
sciences. It sports a modern and intuitive user interface that allows you
to build complex experiments with a minimum of effort. With OpenSesame you
can create a wide range of experiments. The plug-in framework and Python
scripting allow you to incorporate external devices, such as eye trackers,
response boxes, and parallel port devices, into your experiment.

%prep
%setup -q -n %{src_name}-%{version}
%patch0 -p1

# find index.theme the executable file
find . \
-name \*.theme -type f -executable -exec chmod 644 {} \;

%build
# There is nothing to build.

%install
python setup.py install --root=%{buildroot}

# Use path of %%doc macro
rm -f %{buildroot}%{_datadir}/%{name}/COPYING

%fdupes -s %{buildroot}%{_datadir}

%post
%mime_database_post
%desktop_database_post
%icon_theme_cache_post

%postun
%mime_database_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}run
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/mime/packages/x-%{name}-experiment.xml
%{python_sitelib}/openexp
%{python_sitelib}/lib%{name}
%{python_sitelib}/libqt%{name}
%{python_sitelib}/%{name}-%{version}*.egg-info

%changelog
* Tue Jul 12 2016 avvissu@yandex.by
- Update to 3.0.7:
  * Fix 'sound' duration in sampler and sketchpad (#401)
  * Correctly escape slashes in OpenSesame syntax (#403)
  * Don't crash on viewing remote urls ending in .md
  * Fix crashing help menu when off-line (#395)
  * Preserve cursor position when switching to and from inline_script
  items (#390)
  * Give better error message when missing end-of-block line for
    multiline variables
* Sat Mar 12 2016 avvissu@yandex.ru
- Remove python-markdown from recommends
* Fri Feb 26 2016 avvissu@yandex.ru
- Update to 3.0.6:
  * release includes various bugfixes
* Tue Jan 12 2016 avvissu@yandex.ru
- Update to 3.0.5:
  * release includes various bugfixes
* Fri Dec  4 2015 avvissu@yandex.ru
- Update to 3.0.4:
  * release includes various bugfixes
* Fri Nov  6 2015 avvissu@yandex.ru
- Update to 3.0.2:
  * improved validation of variable names in loop item
  * improved validation of OpenSesame-script syntax
  * improved exception handling (including run-status emoticons)
- Change in 3.0.1:
  * give more informative error messages when using invalid variable
    names
  * update auto_example plugin
  * ignore 'undefined name' warnings when validating Python code
    (requires QProgEdit >= 3.1.0)
  * update srbox plugin and add require_state_change_option
  * add explanation how to suppress bug_report messages
- Add Requires: python-webcolors
* Fri Aug 21 2015 avvissu@yandex.ru
- Update to 2.9.7:
  * add append menu to overview and sequence
  * add permanently delete menu option to unused items
  * includes various bugfixes
* Wed Jun  3 2015 avvissu@yandex.ru
- Initial package
